==> paraview_4.1.0+dfsg+1.orig.tar.xz: ParaView-v4.1.0/ParaViewCore/VTKExtensions/Default/vtkPEquivalenceSet.h <==
/*=========================================================================

  Program:   earaView
  Module:    vtkPEquivalenceSet.h

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notice for more information.

  Copyright 2013 Sandia Corporation.
  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
  the U.S. Government retains certain rights in this software.

=========================================================================*/
// .NAME vtkPEquivalenceSet - distributed method of Equivalence
// .SECTION Description
// Same as EquivalenceSet, but resolving is a global operation.
// .SEE vtkEquivalenceSet

#ifndef __vtkPEquivalenceSet_h
#define __vtkPEquivalenceSet_h

#include "vtkPVVTKExtensionsDefaultModule.h" //needed for exports
#include "vtkEquivalenceSet.h"

class VTKPVVTKEXTENSIONSDEFAULT_EXPORT vtkPEquivalenceSet : public vtkEquivalenceSet
{
public:
  vtkTypeMacro(vtkPEquivalenceSet,vtkEquivalenceSet);
  void PrintSelf(ostream& os, vtkIndent indent);
  static vtkPEquivalenceSet *New();

  // Globally equivalent set IDs are reassigned to be sequential.
  virtual int ResolveEquivalences ();

protected:
  vtkPEquivalenceSet();
  ~vtkPEquivalenceSet();

private:
  vtkPEquivalenceSet(const vtkPEquivalenceSet&);  // Not implemented.
  void operator=(const vtkPEquivalenceSet&);  // Not implemented.
};

#endif /* __vtkPEquivalenceSet_h */

==> paraview_5.4.1+dfsg3.orig.tar.xz: ParaView-v5.4.1/ParaViewCore/VTKExtensions/Default/vtkPEquivalenceSet.h <==
/*=========================================================================

  Program:   earaView
  Module:    vtkPEquivalenceSet.h

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notice for more information.

  Copyright 2013 Sandia Corporation.
  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
  the U.S. Government retains certain rights in this software.

=========================================================================*/
/**
 * @class   vtkPEquivalenceSet
 * @brief   distributed method of Equivalence
 *
 * Same as EquivalenceSet, but resolving is a global operation.
 * .SEE vtkEquivalenceSet
*/

#ifndef vtkPEquivalenceSet_h
#define vtkPEquivalenceSet_h

#include "vtkEquivalenceSet.h"
#include "vtkPVVTKExtensionsDefaultModule.h" //needed for exports

class VTKPVVTKEXTENSIONSDEFAULT_EXPORT vtkPEquivalenceSet : public vtkEquivalenceSet
{
public:
  vtkTypeMacro(vtkPEquivalenceSet, vtkEquivalenceSet);
  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
  static vtkPEquivalenceSet* New();

  // Globally equivalent set IDs are reassigned to be sequential.
  virtual int ResolveEquivalences() VTK_OVERRIDE;

protected:
  vtkPEquivalenceSet();
  ~vtkPEquivalenceSet();

private:
  vtkPEquivalenceSet(const vtkPEquivalenceSet&) VTK_DELETE_FUNCTION;
  void operator=(const vtkPEquivalenceSet&) VTK_DELETE_FUNCTION;
};

#endif /* vtkPEquivalenceSet_h */
